VibeSurf Extension

#### Welcome to VibeSurf

Let's vibe surfing the internet with AI automation

🔍
Research Founders
Search information about browser-use and browser-use-webui, write a brief report
📰
HackerNews Summary
Get top 10 news from HackerNews and provide a summary
📈
Stock Market Analysis
Analyze recent week stock market trends for major tech companies

### Chat History

#### Recent Tasks

Last 3 sessions

#### All Sessions

Page 1 of 1

### VibeSurf Settings

### General Settings

Configure application-wide settings

Application Theme
Choose your preferred theme
Default ASR Profile
Default voice recognition profile for speech-to-text
Default TTS Profile
Default text-to-speech profile for voice output

### Environment Variables

Manage environment variables for the application

Environment Variables

### Composio Integration

Connect your Composio account to access external toolkits

⚠️
API Key Required
Please configure your Composio API key to continue
Loading toolkits...

### Add LLM

### Setup Composio API Key

Composio API Key

Your Composio API key for accessing external integrations

Get your API key from
(Project Settings → API Keys)

### Manage Tools

#### Toolkit Name

Loading tools...

### OAuth Authorization Required

🔐

A new browser tab has been opened for OAuth authorization.

Please complete the authorization process and return here.

Have you completed the OAuth authorization?

Connecting to VibeSurf...